<?php
$TRANSLATIONS = array(
"Get the apps to sync your files" => "Obtener les aplicaciones pa sincronizar ficheros",
"Desktop client" => "Cliente d'escritoriu",
"Android app" => "Aplicación d'Android",
"iOS app" => "Aplicación d'iOS",
"Connect your desktop apps to %s" => "Coneuta les tos aplicaciones d'escritoriu a %s",
"Connect your Calendar" => "Coneuta'l to Calendariu",
"Connect your Contacts" => "Coneuta los tos Contautos",
"Documentation" => "Documentación",
"Access files via WebDAV" => "Ficheru d'accesu vía WebDAV",
"There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"http://owncloud.org\">website</a>." => "Hai más información na <a target=\"_blank\" href=\"%s\">documentación y nel nuesu <a target=\"_blank\" href=\"http://owncloud.org\">sitiu web</a>."
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
